@@ -1,4 +1,4 @@
 from .core.defaults import defaults
-from .xmlapi import bngmodel
-from .xmlapi.runner import run
+from .modelapi import bngmodel
+from .modelapi.runner import run
 from .simulator import sim_getter
\ No newline at end of file
